PgIdentifierError

Enum PgIdentifierError 

pub enum PgIdentifierError {
    Empty,
    ContainsDot,
    EmptyQualifiedName,
    InvalidStart {
        character: char,
    },
    InvalidCharacter {
        index: usize,
        character: char,
    },
    ControlCharacter {
        index: usize,
        character: char,
    },
    ReservedKeyword,
    UnterminatedQuotedIdentifier,
    UnescapedQuote,
}
Error returned when PostgreSQL identifier text is rejected.

Variants



Empty

The supplied value was empty.



ContainsDot

A conservative unquoted identifier segment cannot contain ..



EmptyQualifiedName

A qualified name requires at least one segment.



InvalidStart

The supplied value started with an invalid character.

Fields

character: char

The rejected character.



InvalidCharacter

The supplied value contained an invalid unquoted character.

Fields

index: usize

Byte index of the rejected character.

character: char

The rejected character.



ControlCharacter

The supplied value contained a control character.

Fields

index: usize

Byte index of the rejected character.

character: char

The rejected character.



ReservedKeyword

The supplied value was a reserved PostgreSQL keyword-like label.



UnterminatedQuotedIdentifier

A quoted identifier token was missing its closing quote.



UnescapedQuote

A quoted identifier token contained a single embedded quote instead of a doubled quote.